package religion;
our $VERSION = 1;
sub import { "Quia Ego Sic Dico" }
# Morituri Nolumus Mori
$SIG{__DIE__} = sub { die "What business are we in??? We are in the damnation business!!!\n" }; # Whether you like it or not
sub unimport { $SIG{__DIE__} = 'DEFAULT'; die "Infidel!\n" }
q{
Some of the most terrible things in the world are done by people who
think, genuinely think, that they're doing it for the best, especially
if there is some god involved.
};
