#!perl
BEGIN {    # Not knowing what a plan is, magic cargo-cults
  $Test::planned = print "1..2\n"; $Test::ntest = 1;
}
use Test;  # magic claims to be testable
ok (1,1);  # ... but of course it isn't
ok (1,1);  # That's all you need to know.
