package science;
our $VERSION = 1;
sub import { }       # Science is already there.
sub unimport { 0/0 } # That's not going to work.
q{
"As simple as that? You didn't use magic?"
"Only common sense. It's a lot more reliable in the long run."
};
