package magic;
# You are not expected to understand this.
our $VERSION = 1;
sub import   {        $^H{'magic/UNDERSTOOD'} = 1 }
sub unimport { delete $^H{'magic/UNDERSTOOD'}     }
q{
"It's all done by magic, Archchancellor," he said, giving up.
"Ah. Right," said Ridcully. He sounded a little disappointed. "None of that complicated business with springs and cogwheels and tubes and stuff, then."
"That's right, sir," said Ponder. "Just magic. Sufficiently advanced magic."
};
