#!perl
use Test;                                      # Scientific theories are tested
BEGIN { plan tests => 4 }                      # Science is always planned in advance
ok(  1 == 1,  1);                              # Reality is correct
ok(! 1 == 1, !2);                              # Lying to the universe doesn't work
ok(eval "science->import;0" || 1);             # Science evaluates reality as it is
$reality = 1; eval 'no science; $reality = 0'; # ... not as it wishes it to be
ok (defined $reality, !0);                     # Science can't be disabled
